@@ -81,6 +81,8 @@ after_columns_tokens = {
     # oracle
     "STORAGE": "STORAGE",
     "TABLESPACE": "TABLESPACE",
+    # mssql
+    "TEXTIMAGE_ON": "TEXTIMAGE_ON",
 }
 sequence_reserved = {
     "INCREMENT": "INCREMENT",
